@@ -142,7 +142,13 @@ is.adjacent.active(triangle,vi=1,vj=2,onset=2,length=1)
 
 
 ###################################################
-### code chunk number 16: active_default
+### code chunk number 16: get_dyads_active
+###################################################
+get.dyads.active(triangle, at=1)
+
+
+###################################################
+### code chunk number 17: active_default
 ###################################################
 static<-network.initialize(3)
 is.active(static,at=100,v=1:3)
@@ -153,7 +159,7 @@ is.active(dynamic,at=100,v=1:3,active.default=FALSE)
 
 
 ###################################################
-### code chunk number 17: active_default2
+### code chunk number 18: active_default2
 ###################################################
 inactive<-network.initialize(2)
 deactivate.vertices(inactive,onset=-Inf,terminus=Inf,v=2)
@@ -161,7 +167,7 @@ is.active(inactive,onset=Inf,terminus=Inf,v=1:2,active.default=TRUE)
 
 
 ###################################################
-### code chunk number 18: get_change_times
+### code chunk number 19: get_change_times
 ###################################################
 get.change.times(triangle)
 get.change.times(triangle,vertex.activity=FALSE)
@@ -169,14 +175,14 @@ get.change.times(triangle,edge.activity=FALSE)
 
 
 ###################################################
-### code chunk number 19: size_and_edgecount
+### code chunk number 20: size_and_edgecount
 ###################################################
 network.size.active(triangle,onset=2,terminus=3)
 network.edgecount.active(triangle,at=5)
 
 
 ###################################################
-### code chunk number 20: extract
+### code chunk number 21: extract
 ###################################################
 get.change.times(triangle)
 network.edgecount(triangle)
@@ -187,7 +193,7 @@ get.change.times(notflat)
 
 
 ###################################################
-### code chunk number 21: collapse
+### code chunk number 22: collapse
 ###################################################
 flat <-network.collapse(triangle,onset=1,terminus=3)
 is.networkDynamic(flat)
@@ -197,7 +203,7 @@ list.edge.attributes(flat)
 
 
 ###################################################
-### code chunk number 22: collapse2
+### code chunk number 23: collapse2
 ###################################################
 flat <-network.collapse(triangle,onset=1,terminus=3,rm.time.info=FALSE)
 flat%v%'activity.duration'
@@ -206,7 +212,7 @@ flat%e%'activity.duration'
 
 
 ###################################################
-### code chunk number 23: delete_times
+### code chunk number 24: delete_times
 ###################################################
 delete.edge.activity(triangle)
 delete.vertex.activity(triangle)
@@ -215,7 +221,7 @@ get.vertex.activity(triangle)
 
 
 ###################################################
-### code chunk number 24: any_all
+### code chunk number 25: any_all
 ###################################################
 query <- network.initialize(2)
 query[1,2] <-1
@@ -226,7 +232,7 @@ is.active(query,onset=1,terminus=3,rule='any',e=1)
 
 
 ###################################################
-### code chunk number 25: newcomb
+### code chunk number 26: newcomb
 ###################################################
 require(networkDynamic)
 data(newcomb)             # load the data
@@ -238,7 +244,7 @@ get.change.times(newcombDyn)
 
 
 ###################################################
-### code chunk number 26: newcomb2
+### code chunk number 27: newcomb2
 ###################################################
 all(as.sociomatrix(newcomb[[5]]) == 
       as.sociomatrix(network.extract(newcombDyn,at=5)))
@@ -248,7 +254,7 @@ all(as.sociomatrix(newcomb[[5]]) ==
 
 
 ###################################################
-### code chunk number 27: newcomb3
+### code chunk number 28: newcomb3
 ###################################################
 newcombGaps <- networkDynamic(network.list=newcomb,
                       onsets=c(1:8,10:15),termini=c(2:9,11:16))
@@ -256,7 +262,7 @@ get.vertex.activity(newcombGaps)[[1]] # peek at spells for v1
 
 
 ###################################################
-### code chunk number 28: alterNewcombNetObs
+### code chunk number 29: alterNewcombNetObs
 ###################################################
 nobs <-get.network.attribute(newcombGaps,'net.obs.period')
 names(nobs)
@@ -267,7 +273,7 @@ set.network.attribute(newcombGaps,'net.obs.period',nobs)
 
 
 ###################################################
-### code chunk number 29: toggles
+### code chunk number 30: toggles
 ###################################################
 toggles <-cbind(time=1:1000,
                     tail=sample(1:10,1000,replace=TRUE),
@@ -278,7 +284,7 @@ randomNet <-networkDynamic(base.net=empty,edge.toggles=toggles)
 
 
 ###################################################
-### code chunk number 30: toggles2
+### code chunk number 31: toggles2
 ###################################################
 edgeDurations<-get.edge.activity(randomNet,as.spellList=TRUE)$duration
 hist(edgeDurations)
@@ -286,13 +292,13 @@ summary(edgeDurations)
 
 
 ###################################################
-### code chunk number 31: toggles3
+### code chunk number 32: toggles3
 ###################################################
 sum(get.edge.activity(randomNet,as.spellList=TRUE)$terminus.censored)
 
 
 ###################################################
-### code chunk number 32: toggles4
+### code chunk number 33: toggles4
 ###################################################
 nEdgesActive<-sapply(0:1000,
               function(t){network.edgecount.active(randomNet,at=t)})
@@ -300,7 +306,7 @@ plot(nEdgesActive,xlab='timestep',ylab='number of active edges')
 
 
 ###################################################
-### code chunk number 33: file_spells
+### code chunk number 34: file_spells
 ###################################################
 vertexData <-read.table(system.file('extdata/cls33_10_16_96_vertices.tsv', 
             package='networkDynamic'),header=TRUE,stringsAsFactors=FALSE)
@@ -311,20 +317,20 @@ edgeData[1:5,] # peek
 
 
 ###################################################
-### code chunk number 34: assemble_mcfarland
+### code chunk number 35: assemble_mcfarland
 ###################################################
 classDyn <- networkDynamic(vertex.spells=vertexData[,c(3,4,1)],
                            edge.spells=edgeData[,c(3,4,1,2)])
 
 
 ###################################################
-### code chunk number 35: checkDiscrete
+### code chunk number 36: checkDiscrete
 ###################################################
 get.change.times(classDyn)[1:10]
 
 
 ###################################################
-### code chunk number 36: assemble_mcfarland_TEA
+### code chunk number 37: assemble_mcfarland_TEA
 ###################################################
 classDyn <- networkDynamic(vertex.spells=vertexData[,c(3,4,1)],
               edge.spells=edgeData[,c(3,4,1,2,5,6)],
@@ -332,7 +338,7 @@ classDyn <- networkDynamic(vertex.spells=vertexData[,c(3,4,1)],
 
 
 ###################################################
-### code chunk number 37: alterNetObs
+### code chunk number 38: alterNetObs
 ###################################################
 nobs <-get.network.attribute(classDyn,'net.obs.period')
 names(nobs)
@@ -341,13 +347,13 @@ set.network.attribute(classDyn,'net.obs.period',nobs)
 
 
 ###################################################
-### code chunk number 38: mcfarland_vertattr
+### code chunk number 39: mcfarland_vertattr
 ###################################################
 nrow(vertexData)==length(unique(vertexData$vertex_id))
 
 
 ###################################################
-### code chunk number 39: mcfarland_vertexattr2
+### code chunk number 40: mcfarland_vertexattr2
 ###################################################
 set.vertex.attribute(classDyn,"data_id",vertexData$data_id)
 set.vertex.attribute(classDyn,"sex",as.character(vertexData$sex))
@@ -355,7 +361,7 @@ set.vertex.attribute(classDyn,"role",as.character(vertexData$role))
 
 
 ###################################################
-### code chunk number 40: classroom_binning
+### code chunk number 41: classroom_binning
 ###################################################
 classNets <- get.networks(classDyn,start=0,end=50,time.increment=5,rule='latest')
 classDensity <- sapply(classNets, network.density) 
@@ -363,7 +369,7 @@ plot(classDensity,type='l',xlab='network slice #',ylab='density')
 
 
 ###################################################
-### code chunk number 41: class_plots
+### code chunk number 42: class_plots
 ###################################################
 par(mfrow=c(2,2))   # show multiple plots
 plot(network.extract(
@@ -381,27 +387,106 @@ plot(network.extract(
 
 
 ###################################################
-### code chunk number 42: pids1
+### code chunk number 43: reconcile_tri1
+###################################################
+# make a network where the first vertex is not always active
+dirtyData<-networkDynamic(vertex.spells=matrix(c(0,1,1,
+                                                 3,5,1,
+                                                 0,5,2),ncol=3,byrow=TRUE),
+                          edge.spells=matrix(c(0,5,1,2),ncol=4,byrow=TRUE))
+
+network.dynamic.check(dirtyData)$dyad.checks
+# print out the edge spell before ..
+as.data.frame(dirtyData)
+
+
+###################################################
+### code chunk number 44: reconcile_tri2
+###################################################
+reconcile.edge.activity(dirtyData,mode="reduce.to.vertices")
+as.data.frame(dirtyData)
+
+
+###################################################
+### code chunk number 45: reconcile_2
+###################################################
+# before..
+head(get.vertex.activity(classDyn,as.spellList = TRUE))
+# modify vertex spells to encompass all of their incident edges
+reconcile.vertex.activity(classDyn,mode='encompass.edges')
+# after..
+head(get.vertex.activity(classDyn,as.spellList = TRUE))
+
+
+###################################################
+### code chunk number 46: adjust_activity
+###################################################
+adjust.activity(classDyn,factor = 1/60)
+head(get.vertex.activity(classDyn,as.spellList = TRUE))
+
+
+###################################################
+### code chunk number 47: download_paj
+###################################################
+sampFile<-tempfile('days',fileext='.zip')
+download.file('http://vlado.fmf.uni-lj.si/pub/networks/data/esna/Sampson.zip',sampFile)
+sampData<-read.paj(unz(sampFile,'Sampson.paj'),
+                   time.format='networkDynamic',
+                   edge.name = 'liked')
+names(sampData)
+
+
+###################################################
+### code chunk number 48: sampson_format
+###################################################
+sampData$partitions
+sampData$networks[[1]]
+
+sampDyn<-get.inducedSubgraph(sampData$networks[[1]], eid=which(sampData$networks[[1]]%e%'liked' > 0))
+sampDyn%v%'cloisterville'<-sampData$partitions$Sampson_cloisterville
+
+
+###################################################
+### code chunk number 49: sampson_plot
+###################################################
+par(mfcol=c(2,2))
+plot(network.extract(sampDyn,at=1),vertex.col='cloisterville', 
+     edge.col='gray', label.cex=0.6,
+     displaylabels=TRUE, main='Sampson "like" net at time 1')
+plot(network.extract(sampDyn,at=2),vertex.col='cloisterville', 
+     edge.col='gray',label.cex=0.6,
+     displaylabels=TRUE, main='Sampson "like" net at time 2')
+plot(network.extract(sampDyn,at=3),vertex.col='cloisterville', 
+     edge.col='gray',label.cex=0.6,
+     displaylabels=TRUE, main='Sampson "like" net at time 3')
+plot(network.extract(sampDyn,at=5),vertex.col='cloisterville', 
+     edge.col='gray',label.cex=0.6,
+     displaylabels=TRUE, main='Sampson "like" net at time 5')
+par(mfcol=c(1,1))
+
+
+###################################################
+### code chunk number 50: pids1
 ###################################################
 haystack<-network.initialize(30)
 activate.vertices(haystack,v=10:20)
 
 
 ###################################################
-### code chunk number 43: pids2
+### code chunk number 51: pids2
 ###################################################
 set.vertex.attribute(haystack,'needle',TRUE,v=sample(10:20,2))
 
 
 ###################################################
-### code chunk number 44: pids3
+### code chunk number 52: pids3
 ###################################################
 set.vertex.attribute(haystack,'hayId',paste('straw',1:30,sep=''))
 set.network.attribute(haystack,'vertex.pid','hayId')
 
 
 ###################################################
-### code chunk number 45: pids4
+### code chunk number 53: pids4
 ###################################################
 newstack<-network.extract(haystack,at=100,active.default=FALSE)
 network.size(newstack)
@@ -410,20 +495,20 @@ needleIds
 
 
 ###################################################
-### code chunk number 46: pids5
+### code chunk number 54: pids5
 ###################################################
 get.vertex.pid(newstack,needleIds)
 get.vertex.id(haystack,get.vertex.pid(newstack,needleIds))
 
 
 ###################################################
-### code chunk number 47: pids6
+### code chunk number 55: pids6
 ###################################################
 set.network.attribute(classDyn,'vertex.pid','data_id')
 
 
 ###################################################
-### code chunk number 48: nonpid_delete_example
+### code chunk number 56: nonpid_delete_example
 ###################################################
 net<-network.initialize(3)
 add.vertices(net,1)
@@ -433,7 +518,7 @@ as.matrix(net)
 
 
 ###################################################
-### code chunk number 49: pid_delete_example
+### code chunk number 57: pid_delete_example
 ###################################################
 net<-network.initialize(3)
 set.network.attribute(net,'vertex.pid','vertex.names')
@@ -444,7 +529,7 @@ as.matrix(net)
 
 
 ###################################################
-### code chunk number 50: initialize.pids
+### code chunk number 58: initialize.pids
 ###################################################
 net<-network.initialize(3)
 add.edges(net,tail=1:2,head=2:3)
@@ -454,41 +539,41 @@ net%e%'edge.pid'
 
 
 ###################################################
-### code chunk number 51: newcomb_spells
+### code chunk number 59: newcomb_spells
 ###################################################
 newcombEdgeSpells<-get.edge.activity(newcombDyn,as.spellList=TRUE)
 newcombEdgeSpells[1:5,] # peek at the beginning
 
 
 ###################################################
-### code chunk number 52: newcomb_dataframe
+### code chunk number 60: newcomb_dataframe
 ###################################################
 newcombEdgeSpells<-as.data.frame(newcombDyn)
 newcombEdgeSpells[1:5,] # peek at the beginning
 
 
 ###################################################
-### code chunk number 53: newcomb_vertspells
+### code chunk number 61: newcomb_vertspells
 ###################################################
 vertSpells <- get.vertex.activity(newcombDyn,as.spellList=TRUE)
 vertSpells[1:5,]
 
 
 ###################################################
-### code chunk number 54: slice_nets
+### code chunk number 62: slice_nets
 ###################################################
 lapply(get.networks(randomNet,start=0,end=2,time.increment=1),as.matrix)
 
 
 ###################################################
-### code chunk number 55: slice_nets2
+### code chunk number 63: slice_nets2
 ###################################################
 newSlices<-get.networks(newcombGaps)
 sapply(newSlices,network.size)
 
 
 ###################################################
-### code chunk number 56: tea1
+### code chunk number 64: tea1
 ###################################################
 net <-network.initialize(5)
 activate.vertex.attribute(net,"happiness", -1, onset=0,terminus=1)
@@ -500,7 +585,7 @@ get.vertex.attribute(net,"happiness.active",unlist=FALSE)[[1]]
 
 
 ###################################################
-### code chunk number 57: tea1.1
+### code chunk number 65: tea1.1
 ###################################################
 activate.network.attribute(net,'colors',"red",
                            onset=0,terminus=1)
@@ -512,7 +597,7 @@ activate.edge.attribute(net,'weight',c(1,2,1),onset=3,terminus=7)
 
 
 ###################################################
-### code chunk number 58: tea2
+### code chunk number 66: tea2
 ###################################################
 get.vertex.attribute.active(net,"happiness",at=3.5)
 get.vertex.attribute.active(net,"happiness",
@@ -522,13 +607,13 @@ get.vertex.attribute.active(net,"happiness",
 
 
 ###################################################
-### code chunk number 59: tea3
+### code chunk number 67: tea3
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5)
 
 
 ###################################################
-### code chunk number 60: tea3_hidden
+### code chunk number 68: tea3_hidden
 ###################################################
 cat('Warning message:
 In get.vertex.attribute.active(net, "happiness", onset = 2.5, 
@@ -537,26 +622,26 @@ In get.vertex.attribute.active(net, "happiness", onset = 2.5,
 
 
 ###################################################
-### code chunk number 61: tea3.1
+### code chunk number 69: tea3.1
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5,rule='earliest')
 
 
 ###################################################
-### code chunk number 62: tea3.2
+### code chunk number 70: tea3.2
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5,rule='latest')
 
 
 ###################################################
-### code chunk number 63: tea4
+### code chunk number 71: tea4
 ###################################################
 get.vertex.attribute.active(net,"happiness",onset=2.5,terminus=4.5,
                         return.tea=TRUE)[[1]]
 
 
 ###################################################
-### code chunk number 64: tea5
+### code chunk number 72: tea5
 ###################################################
 sapply(get.vertex.attribute.active(net,"happiness",onset=0,terminus=7,
                   return.tea=TRUE),function(splist){
@@ -565,14 +650,14 @@ sapply(get.vertex.attribute.active(net,"happiness",onset=0,terminus=7,
 
 
 ###################################################
-### code chunk number 65: tea5.1
+### code chunk number 73: tea5.1
 ###################################################
 get.edge.attribute.active(net,'weight',at=2)
 get.edge.attribute.active(net,'weight',at=5)
 
 
 ###################################################
-### code chunk number 66: listtea
+### code chunk number 74: listtea
 ###################################################
 list.vertex.attributes.active(net,at=2)
 list.edge.attributes.active(net,at=2)
@@ -580,21 +665,28 @@ list.network.attributes.active(net,at=2,dynamic.only=TRUE)
 
 
 ###################################################
-### code chunk number 67: tea6
+### code chunk number 75: <when_attr_match
+###################################################
+when.vertex.attrs.match(net,"happiness",2)
+when.edge.attrs.match(net,'weight',10, match.op = '>')
+
+
+###################################################
+### code chunk number 76: tea6
 ###################################################
 activate.vertex.attribute(net, "happiness",100, onset=0,terminus=10,v=1)
 get.vertex.attribute.active(net,"happiness",at=2)
 
 
 ###################################################
-### code chunk number 68: tea7
+### code chunk number 77: tea7
 ###################################################
 deactivate.vertex.attribute(net, "happiness",onset=1,terminus=10,v=2)
 get.vertex.attribute.active(net,"happiness",at=2)
 
 
 ###################################################
-### code chunk number 69: windsurfers
+### code chunk number 78: windsurfers
 ###################################################
 data(windsurfers)    # let's go to the beach!
 range(get.change.times(windsurfers))
@@ -603,7 +695,7 @@ sapply(0:31,function(t){ # how many people in net each day?
 
 
 ###################################################
-### code chunk number 70: windsurfers_meta
+### code chunk number 79: windsurfers_meta
 ###################################################
 list.network.attributes.active(windsurfers,-Inf,Inf,dynamic.only=TRUE)
 par(mfcol=c(2,1)) # show multiple plots
@@ -619,7 +711,7 @@ par(mfcol=c(1,1))
 
 
 ###################################################
-### code chunk number 71: windsurfers_meta2
+### code chunk number 80: windsurfers_meta2
 ###################################################
 day3 <-network.collapse(windsurfers,at=2)
 day3%n%'day' # what day of the week is day 3?
@@ -627,7 +719,7 @@ day3%n%'atmp' # air temp?
 
 
 ###################################################
-### code chunk number 72: windsim
+### code chunk number 81: windsim
 ###################################################
 runSim<-function(net,timeStep,transProb){
   # loop through time, updating states
@@ -665,13 +757,13 @@ runSim<-function(net,timeStep,transProb){
 
 
 ###################################################
-### code chunk number 73: setseed
+### code chunk number 82: setseed
 ###################################################
 set.seed(123) # so we will get the same results each time the document is built
 
 
 ###################################################
-### code chunk number 74: windsim_params
+### code chunk number 83: windsim_params
 ###################################################
 timeStep <- 1  # units are in days
 transProb <- 0.2 # how likely to tell in each conversation/day
@@ -684,7 +776,7 @@ windsurfers<-runSim(windsurfers,timeStep,transProb) # run it!
 
 
 ###################################################
-### code chunk number 75: windsim_plots
+### code chunk number 84: windsim_plots
 ###################################################
 par(mfcol=c(1,2)) # show two plots side by side
 wind7<-network.extract(windsurfers,at=7)
@@ -705,7 +797,7 @@ par(mfcol=c(1,1))
 
 
 ###################################################
-### code chunk number 76: windsim_stats
+### code chunk number 85: windsim_stats
 ###################################################
 get.vertex.attribute.active(windsurfers,'knowsRumor',at=15)
 plot(sapply(0:31,function(t){
@@ -716,7 +808,7 @@ plot(sapply(0:31,function(t){
 
 
 ###################################################
-### code chunk number 77: windsim_extract
+### code chunk number 86: windsim_extract
 ###################################################
 # pull TEA from v3, extract values from 1st part and unlist
 unlist(get.vertex.attribute.active(windsurfers,'heardRumorFrom',
@@ -727,7 +819,7 @@ get.vertex.attribute.active(windsurfers,'heardRumorFrom',
 
 
 ###################################################
-### code chunk number 78: windsim_tree
+### code chunk number 87: windsim_tree
 ###################################################
 transTree<-function(net){
   # for each vertex in net who knows
@@ -756,13 +848,13 @@ plot(transTree(windsurfers),displaylabels=TRUE,
 
 
 ###################################################
-### code chunk number 79: citation
+### code chunk number 88: citation
 ###################################################
 citation(package='networkDynamic')
 
 
 ###################################################
-### code chunk number 80: package_listing
+### code chunk number 89: package_listing
 ###################################################
 cat(ls("package:networkDynamic"),sep="\n")
 
